@@ -8,17 +8,17 @@ def sharpe(token, ticker, date):
     return round(float(response),2)
 
 def volatility(token, ticker, date): 
-    url = "https://spawnerapi.com/sharpe/" + ticker + "/" + date + "/" + token
+    url = "https://spawnerapi.com/volatility/" + ticker + "/" + date + "/" + token
     response = requests.get(url).text
     return round(float(response), 2)
 
 def expected_return(token, ticker, date): 
-    url = "https://spawnerapi.com/sharpe/" + ticker + "/" + date + "/" + token
+    url = "https://spawnerapi.com/expected-return/" + ticker + "/" + date + "/" + token
     response = requests.get(url).text
     return round(float(response),2)
 
 def kelly_criterion(token, ticker, date): 
-    url = "https://spawnerapi.com/sharpe/" + ticker + "/" + date + "/" + token
+    url = "https://spawnerapi.com/kelly-criterion/" + ticker + "/" + date + "/" + token
     response = requests.get(url).text
     return round(float(response),2)
 
